@@ -76,7 +76,7 @@ def DerIvGet(SecID, beginDate, endDate, optID = "", field = "", pandas = "1"):
     if split_param is None:
         csvString = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
         if csvString is None or len(csvString) == 0 or (csvString[0] == '-' and not api_base.is_no_data_warn(csvString, False)) or csvString[0] == '{':
-            api_base.handle_error(csvString, 1518)
+            api_base.handle_error(csvString, 'DerIvGet')
         elif csvString[:2] == '-1':
             csvString = ''
     else:
@@ -86,11 +86,11 @@ def DerIvGet(SecID, beginDate, endDate, optID = "", field = "", pandas = "1"):
             requestString[split_index] = ','.join(item)
             temp_result = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
             if temp_result is None or len(temp_result) == 0 or temp_result[0] == '{' or (temp_result[0] == '-' and not api_base.is_no_data_warn(temp_result, False)):
-                api_base.handle_error(temp_result, 1518)
+                api_base.handle_error(temp_result, 'DerIvGet')
             if temp_result[:2] != '-1':
                 csvString.append(temp_result if len(csvString) == 0 else temp_result[temp_result.find('\n')+1:])
         csvString = ''.join(csvString)
-
+    
     if len(csvString) == 0:
         if 'field' not in locals() or len(field) == 0:
             field = [u'SecID', u'ticker', u'exchangeCD', u'secShortName', u'tradeDate', u'closePriceAdj', u'optID', u'expDate', u'strikePrice', u'contractType', u'sontractStyle', u'ask', u'bid', u'meanPrice', u'settlePrice', u'IV', u'turnoverVol', u'openInt', u'closePriceUnadj', u'forwardPrice', u'isInterPolated', u'delta', u'vega', u'gamma', u'theta', u'rho']
@@ -172,7 +172,7 @@ def DerIvHvGet(SecID, beginDate, endDate, period = "", field = "", pandas = "1")
     if split_param is None:
         csvString = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
         if csvString is None or len(csvString) == 0 or (csvString[0] == '-' and not api_base.is_no_data_warn(csvString, False)) or csvString[0] == '{':
-            api_base.handle_error(csvString, 1519)
+            api_base.handle_error(csvString, 'DerIvHvGet')
         elif csvString[:2] == '-1':
             csvString = ''
     else:
@@ -182,11 +182,11 @@ def DerIvHvGet(SecID, beginDate, endDate, period = "", field = "", pandas = "1")
             requestString[split_index] = ','.join(item)
             temp_result = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
             if temp_result is None or len(temp_result) == 0 or temp_result[0] == '{' or (temp_result[0] == '-' and not api_base.is_no_data_warn(temp_result, False)):
-                api_base.handle_error(temp_result, 1519)
+                api_base.handle_error(temp_result, 'DerIvHvGet')
             if temp_result[:2] != '-1':
                 csvString.append(temp_result if len(csvString) == 0 else temp_result[temp_result.find('\n')+1:])
         csvString = ''.join(csvString)
-
+    
     if len(csvString) == 0:
         if 'field' not in locals() or len(field) == 0:
             field = [u'SecID', u'ticker', u'exchangeCD', u'tradeDate', u'closePriceUnadj', u'period', u'hv']
@@ -268,7 +268,7 @@ def DerIvIndexGet(SecID, beginDate, endDate, period = "", field = "", pandas = "
     if split_param is None:
         csvString = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
         if csvString is None or len(csvString) == 0 or (csvString[0] == '-' and not api_base.is_no_data_warn(csvString, False)) or csvString[0] == '{':
-            api_base.handle_error(csvString, 1520)
+            api_base.handle_error(csvString, 'DerIvIndexGet')
         elif csvString[:2] == '-1':
             csvString = ''
     else:
@@ -278,11 +278,11 @@ def DerIvIndexGet(SecID, beginDate, endDate, period = "", field = "", pandas = "
             requestString[split_index] = ','.join(item)
             temp_result = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
             if temp_result is None or len(temp_result) == 0 or temp_result[0] == '{' or (temp_result[0] == '-' and not api_base.is_no_data_warn(temp_result, False)):
-                api_base.handle_error(temp_result, 1520)
+                api_base.handle_error(temp_result, 'DerIvIndexGet')
             if temp_result[:2] != '-1':
                 csvString.append(temp_result if len(csvString) == 0 else temp_result[temp_result.find('\n')+1:])
         csvString = ''.join(csvString)
-
+    
     if len(csvString) == 0:
         if 'field' not in locals() or len(field) == 0:
             field = [u'SecID', u'ticker', u'exchangeCD', u'tradeDate', u'closePriceAdj', u'period', u'ivIndexCall', u'ivIndexPut', u'ivIndexMean']
@@ -375,7 +375,7 @@ def DerIvIvpDeltaGet(SecID, beginDate, endDate, period = "", delta = "", field =
     if split_param is None:
         csvString = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
         if csvString is None or len(csvString) == 0 or (csvString[0] == '-' and not api_base.is_no_data_warn(csvString, False)) or csvString[0] == '{':
-            api_base.handle_error(csvString, 1521)
+            api_base.handle_error(csvString, 'DerIvIvpDeltaGet')
         elif csvString[:2] == '-1':
             csvString = ''
     else:
@@ -385,11 +385,11 @@ def DerIvIvpDeltaGet(SecID, beginDate, endDate, period = "", delta = "", field =
             requestString[split_index] = ','.join(item)
             temp_result = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
             if temp_result is None or len(temp_result) == 0 or temp_result[0] == '{' or (temp_result[0] == '-' and not api_base.is_no_data_warn(temp_result, False)):
-                api_base.handle_error(temp_result, 1521)
+                api_base.handle_error(temp_result, 'DerIvIvpDeltaGet')
             if temp_result[:2] != '-1':
                 csvString.append(temp_result if len(csvString) == 0 else temp_result[temp_result.find('\n')+1:])
         csvString = ''.join(csvString)
-
+    
     if len(csvString) == 0:
         if 'field' not in locals() or len(field) == 0:
             field = [u'SecID', u'ticker', u'exchangeCD', u'tradeDate', u'closePriceUnadj', u'period', u'delta', u'moneyness', u'strikePrice', u'IV']
@@ -471,7 +471,7 @@ def DerIvParamGet(SecID, beginDate, endDate, expDate = "", field = "", pandas =
     if split_param is None:
         csvString = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
         if csvString is None or len(csvString) == 0 or (csvString[0] == '-' and not api_base.is_no_data_warn(csvString, False)) or csvString[0] == '{':
-            api_base.handle_error(csvString, 1522)
+            api_base.handle_error(csvString, 'DerIvParamGet')
         elif csvString[:2] == '-1':
             csvString = ''
     else:
@@ -481,11 +481,11 @@ def DerIvParamGet(SecID, beginDate, endDate, expDate = "", field = "", pandas =
             requestString[split_index] = ','.join(item)
             temp_result = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
             if temp_result is None or len(temp_result) == 0 or temp_result[0] == '{' or (temp_result[0] == '-' and not api_base.is_no_data_warn(temp_result, False)):
-                api_base.handle_error(temp_result, 1522)
+                api_base.handle_error(temp_result, 'DerIvParamGet')
             if temp_result[:2] != '-1':
                 csvString.append(temp_result if len(csvString) == 0 else temp_result[temp_result.find('\n')+1:])
         csvString = ''.join(csvString)
-
+    
     if len(csvString) == 0:
         if 'field' not in locals() or len(field) == 0:
             field = [u'SecID', u'ticker', u'exchangeCD', u'expDate', u'tradeDate', u'closePriceUnadj', u'forwardPrice', u'parabolaA', u'parabolaB', u'parabolaC']
@@ -578,7 +578,7 @@ def DerIvRawDeltaGet(SecID, beginDate, endDate, period = "", delta = "", field =
     if split_param is None:
         csvString = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
         if csvString is None or len(csvString) == 0 or (csvString[0] == '-' and not api_base.is_no_data_warn(csvString, False)) or csvString[0] == '{':
-            api_base.handle_error(csvString, 1523)
+            api_base.handle_error(csvString, 'DerIvRawDeltaGet')
         elif csvString[:2] == '-1':
             csvString = ''
     else:
@@ -588,11 +588,11 @@ def DerIvRawDeltaGet(SecID, beginDate, endDate, period = "", delta = "", field =
             requestString[split_index] = ','.join(item)
             temp_result = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
             if temp_result is None or len(temp_result) == 0 or temp_result[0] == '{' or (temp_result[0] == '-' and not api_base.is_no_data_warn(temp_result, False)):
-                api_base.handle_error(temp_result, 1523)
+                api_base.handle_error(temp_result, 'DerIvRawDeltaGet')
             if temp_result[:2] != '-1':
                 csvString.append(temp_result if len(csvString) == 0 else temp_result[temp_result.find('\n')+1:])
         csvString = ''.join(csvString)
-
+    
     if len(csvString) == 0:
         if 'field' not in locals() or len(field) == 0:
             field = [u'SecID', u'ticker', u'tradeDate', u'closePriceUnadj', u'period', u'delta', u'moneyness', u'strikePrice', u'IV']
@@ -674,7 +674,7 @@ def DerIvSurfaceGet(SecID, beginDate, endDate, contractType = "", field = "", pa
     if split_param is None:
         csvString = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
         if csvString is None or len(csvString) == 0 or (csvString[0] == '-' and not api_base.is_no_data_warn(csvString, False)) or csvString[0] == '{':
-            api_base.handle_error(csvString, 1524)
+            api_base.handle_error(csvString, 'DerIvSurfaceGet')
         elif csvString[:2] == '-1':
             csvString = ''
     else:
@@ -684,11 +684,11 @@ def DerIvSurfaceGet(SecID, beginDate, endDate, contractType = "", field = "", pa
             requestString[split_index] = ','.join(item)
             temp_result = api_base.__getCSV__(''.join(requestString), httpClient, gw=True)
             if temp_result is None or len(temp_result) == 0 or temp_result[0] == '{' or (temp_result[0] == '-' and not api_base.is_no_data_warn(temp_result, False)):
-                api_base.handle_error(temp_result, 1524)
+                api_base.handle_error(temp_result, 'DerIvSurfaceGet')
             if temp_result[:2] != '-1':
                 csvString.append(temp_result if len(csvString) == 0 else temp_result[temp_result.find('\n')+1:])
         csvString = ''.join(csvString)
-
+    
     if len(csvString) == 0:
         if 'field' not in locals() or len(field) == 0:
             field = [u'SecID', u'ticker', u'tradeDate', u'closePriceUnadj', u'period', u'strike', u'outOfMoney', u'contractType', u'IV', u'delta']
