@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # 通联数据机密
 # --------------------------------------------------------------------
-# 通联数据股份公司版权所有 © 2013-2021
+# 通联数据股份公司版权所有 © 2013-2022
 #
 # 注意：本文所载所有信息均属于通联数据股份公司资产。本文所包含的知识和技术概念均属于
 # 通联数据产权，并可能由中国、美国和其他国家专利或申请中的专利所覆盖，并受商业秘密或
@@ -10,7 +10,7 @@
 #
 # DataYes CONFIDENTIAL
 # --------------------------------------------------------------------
-# Copyright © 2013-2021 DataYes, All Rights Reserved.
+# Copyright © 2013-2022 DataYes, All Rights Reserved.
 #
 # NOTICE: All information contained herein is the property of DataYes
 # Incorporated. The intellectual and technical concepts contained herein are
@@ -25,6 +25,7 @@ __all__ = ['ideal', 'long_only', 'long_short', 'limit_active_risk', 'limit_portf
 import pandas as pd
 
 from .SignalAnalysis.tears import portfolio_construction
+from .utils import Authorization
 
 _OPTIMIZER_RETURN_FIELDS = [
     'trade_volume',
@@ -48,9 +49,10 @@ def print_validate_factor_frame(factor_frame):
     return not is_all_null
 
 
+@Authorization('uqer.py.PortfolioConstruction')
 def ideal(
         factor_frame, start_date, end_date, freq, universe='HS300', benchmark='HS300',
-        init_cash=1e8, init_holding=None
+        init_cash=1e8, init_holding=None, risk_model_version='dy_cne5_old'
 ):
     """
     :param factor_frame: 因子数据, DataFrame(factor_values, index=dates, columns=tickers)
@@ -64,10 +66,13 @@ def ideal(
                       支持自定义指数,即dict of Series/dict of dict形式定义的benchmark
     :param init_cash: int/float, 初始资金，默认1e8
     :param init_holding: dict/pd.Series/None, 每个个股的初始市值，不包含现金
+    :param risk_model_version: str, 选择不同的风险模型作为组合优化的约束依据
     :return: dict
     """
     if not print_validate_factor_frame(factor_frame):
         return
+    if risk_model_version not in ['dy_cne5_old', 'dy_cne5_new']:
+        raise Exception("risk_model_version仅支持dy_cne5_old/dy_cne5_new")
 
     tickers = factor_frame.columns.values
     if len(tickers[0]) > 6:
@@ -101,6 +106,7 @@ def ideal(
     return result
 
 
+@Authorization('uqer.py.PortfolioConstruction')
 def long_only(
         factor_frame, start_date, end_date, freq, universe='HS300', benchmark='HS300',
         top_ratio=0.2, select_type=1, weight_type='equal', init_cash=1e8, init_holding=None,
@@ -160,6 +166,7 @@ def long_only(
     return result
 
 
+@Authorization('uqer.py.PortfolioConstruction')
 def long_short(
         factor_frame, start_date, end_date, freq, universe='HS300', benchmark='HS300',
         top_ratio=0.2, down_ratio=0.2, select_type=1, weight_type='equal', init_cash=1e8, init_holding=None,
@@ -220,6 +227,7 @@ def long_short(
     return result
 
 
+@Authorization('uqer.py.PortfolioConstruction')
 def limit_active_risk(
         factor_frame, start_date, end_date, freq, universe='HS300', benchmark='HS300', price_type='open',
         target_risk=0.3, target_turnover=None, fee=0, init_cash=1e8, init_holding=None,
@@ -227,7 +235,8 @@ def limit_active_risk(
         asset_cons_method='absolute', asset_cons_type='by_value',
         factor_exposure_lower_boundary=-10, factor_exposure_upper_boundary=10,
         sector_exposure_lower_boundary=-10, sector_exposure_upper_boundary=10,
-        risk_aversion=0, soft_params=None, cash_boundary=None
+        risk_aversion=0, soft_params=None, cash_boundary=None, risk_model_version='dy_cne5_old',
+        asset_group_lower_boundary={}, asset_group_upper_boundary={}
 ):
     """
     :param factor_frame:
@@ -257,6 +266,9 @@ def limit_active_risk(
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
     :param cash_boundary: list of float, 现金约束,默认[0.0,0.01],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
+    :param asset_group_lower_boundary: 分组资产权重总和约束下界, dict, key为调仓日期，value为list of Series
+    :param asset_group_upper_boundary: 分组资产权重总和约束上界, dict, key为调仓日期，value为list of Series
+    :param risk_model_version: str, 可以选择不同的风险模型作为组合优化的约束依据
     :return: dict
     """
     if soft_params is None:
@@ -281,6 +293,8 @@ def limit_active_risk(
         raise Exception('asset_cons_method not in ["absolute","active"]')
     if asset_cons_type not in ['by_value', 'by_percent']:
         raise Exception('asset_cons_type not in ["by_value","by_percent"]')
+    if risk_model_version not in ['dy_cne5_old', 'dy_cne5_new']:
+        raise Exception("risk_model_version仅支持dy_cne5_old/dy_cne5_new")
 
     result = portfolio_construction(
         factor_value_frame=factor_value_frame,
@@ -304,9 +318,12 @@ def limit_active_risk(
         factor_exposure_upper_boundary=factor_exposure_upper_boundary,
         sector_exposure_lower_boundary=sector_exposure_lower_boundary,
         sector_exposure_upper_boundary=sector_exposure_upper_boundary,
+        asset_group_lower_boundary=asset_group_lower_boundary,
+        asset_group_upper_boundary=asset_group_upper_boundary,
         risk_aversion=risk_aversion,
         soft_params=soft_params,
-        cash_boundary=cash_boundary
+        cash_boundary=cash_boundary,
+        risk_model_version=risk_model_version,
     )
     if result:
         result = {
@@ -316,6 +333,7 @@ def limit_active_risk(
     return result
 
 
+@Authorization('uqer.py.PortfolioConstruction')
 def limit_portfolio_risk(
         factor_frame, start_date, end_date, freq, universe='HS300', benchmark='HS300', price_type='open',
         target_risk=0.3, target_turnover=None, fee=0, init_cash=1e8, init_holding=None,
@@ -323,7 +341,8 @@ def limit_portfolio_risk(
         asset_cons_method='absolute', asset_cons_type='by_value',
         factor_exposure_lower_boundary=-10, factor_exposure_upper_boundary=10,
         sector_exposure_lower_boundary=-10, sector_exposure_upper_boundary=10,
-        risk_aversion=0, soft_params=None, cash_boundary=None
+        risk_aversion=0, soft_params=None, cash_boundary=None, risk_model_version='dy_cne5_old',
+        asset_group_lower_boundary={}, asset_group_upper_boundary={}
 ):
     """
     :param factor_frame:
@@ -353,6 +372,9 @@ def limit_portfolio_risk(
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
     :param cash_boundary: list of float, 现金约束,默认[0.0,0.01],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
+    :param asset_group_lower_boundary: 分组资产权重总和约束下界, dict, key为调仓日期，value为list of Series
+    :param asset_group_upper_boundary: 分组资产权重总和约束上界, dict, key为调仓日期，value为list of Series
+    :param risk_model_version: str, 可以选择不同的风险模型作为组合优化的约束依据
     :return: dict
     """
     if soft_params is None:
@@ -378,6 +400,8 @@ def limit_portfolio_risk(
         raise Exception('asset_cons_method not in ["absolute","active"]')
     if asset_cons_type not in ['by_value', 'by_percent']:
         raise Exception('asset_cons_type not in ["by_value","by_percent"]')
+    if risk_model_version not in ['dy_cne5_old', 'dy_cne5_new']:
+        raise Exception("risk_model_version仅支持dy_cne5_old/dy_cne5_new")
 
     result = portfolio_construction(
         factor_value_frame=factor_value_frame,
@@ -401,6 +425,8 @@ def limit_portfolio_risk(
         factor_exposure_upper_boundary=factor_exposure_upper_boundary,
         sector_exposure_lower_boundary=sector_exposure_lower_boundary,
         sector_exposure_upper_boundary=sector_exposure_upper_boundary,
+        asset_group_lower_boundary=asset_group_lower_boundary,
+        asset_group_upper_boundary=asset_group_upper_boundary,
         risk_aversion=risk_aversion,
         soft_params=soft_params,
         cash_boundary=cash_boundary
