@@ -1,6 +1,6 @@
 #coding=utf-8
 
-from .signal_process import neutralize, standardize, winsorize
+from .signal_process import neutralize, standardize, winsorize, neutralize_pit
 from .portfolio_construct import simple_long_only, long_only
 
 
