@@ -24,12 +24,15 @@ session = requests.Session()
 class Client(Authorize):
     """优矿
     """
-    def __init__(self, username='', password='', token='', account_file='', data_target_path='', notebook_target_path=''):
+    def __init__(self, token='', data_target_path='', notebook_target_path=''):
 
-        Authorize.__init__(self, username, password, token, account_file, session)
-        
-        ### Authorize
-        self._authorize()
+        Authorize.__init__(self, token, session)
+
+        try:
+            ### Authorize
+            self._authorize()
+        except SystemExit:
+            raise
 
         if self._isvalid:
             ### Trading
